@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Hewlett-Packard Development Company, L.P.
+# (C) Copyright 2015-2016 Hewlett Packard Enterprise Development Company LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,6 +28,9 @@ def alarm(metrics):
             "alarmName": "test Alarm",
             "oldState": "OK",
             "newState": "ALARM",
+            "severity": "LOW",
+            "link": "some-link",
+            "lifecycleState": "OPEN",
             "stateChangeReason": "I am alarming!",
             "timestamp": time.time(),
             "metrics": metrics}
